<?php
/*
Plugin Name: Simple Custom Login Logo
Plugin URI:  https://stelnyk.com/wp-custom-login-logo
Description: A simple plugin to change the logo on the WordPress login page.
Version:     1.0
Author:      Nick Stelnyk
Author URI:  https://stelnyk.com
License:     GPLv2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: wpcll
*/

// Enqueue the media uploader and color picker script
function custom_login_logo_enqueue_media() {
    if ( isset( $_GET['page'] ) && $_GET['page'] == 'custom-login-logo' ) {
        wp_enqueue_media();
        wp_enqueue_script( 
            'custom-login-logo-script', 
            plugin_dir_url( __FILE__ ) . 'wpcll.js', 
            array( 'jquery' ), 
            '1.0', // Add version number
            true 
        );
        wp_enqueue_style( 'wp-color-picker' );
        wp_enqueue_script( 
            'custom-login-color-script', 
            plugin_dir_url( __FILE__ ) . 'wpcll.js', 
            array( 'wp-color-picker' ), 
            '1.0', // Add version number
            true 
        );
    }
}
add_action( 'admin_enqueue_scripts', 'custom_login_logo_enqueue_media' );

// Add custom logo and background color to login page
function custom_login_logo_and_background() {
    $logo_url = get_option('custom_login_logo');
    $background_color = get_option('custom_login_background_color', '#ffffff'); // Default to white background
    ?>
    <style type="text/css">
        body.login {
            background-color: <?php echo esc_attr( $background_color ); ?>;
        }
        #login h1 a {
            background-image: url('<?php echo esc_url( $logo_url ); ?>');
            width: 100%;
            height: 100px; /* Adjust height */
            background-size: contain;
            background-repeat: no-repeat;
            margin-bottom: 20px;
        }
    </style>
    <?php
}
add_action('login_enqueue_scripts', 'custom_login_logo_and_background');

// Add settings to the WordPress Settings menu
function custom_login_logo_menu() {
    add_options_page(
        'Custom Login Logo', // Page title
        'Custom Login Logo', // Menu title
        'manage_options', // Capability
        'custom-login-logo', // Menu slug
        'custom_login_logo_settings_page' // Function to display the page content
    );
}
add_action('admin_menu', 'custom_login_logo_menu');

// Settings page content
function custom_login_logo_settings_page() {
    ?>
    <div class="wrap">
        <h1>Custom Login Logo</h1>
        <form method="post" action="<?php echo esc_url( admin_url('admin-post.php') ); ?>">
            <?php
            settings_fields( 'custom_login_logo_settings' );
            do_settings_sections( 'custom-login-logo' );

            // Add nonce for verification
            wp_nonce_field( 'custom_login_logo_nonce_action', 'custom_login_logo_nonce' );

            // Hidden input to specify the action
            echo '<input type="hidden" name="action" value="custom_login_logo_save_settings" />';

            submit_button();
            ?>
        </form>
    </div>
    <?php
}

// Initialize settings
function custom_login_logo_settings_init() {
    register_setting( 'custom_login_logo_settings', 'custom_login_logo' );
    register_setting( 'custom_login_logo_settings', 'custom_login_background_color' );

    add_settings_section(
        'custom_login_logo_section',
        '',
        null,
        'custom-login-logo'
    );

    add_settings_field(
        'custom_login_logo',
        'Upload Custom Login Logo',
        'custom_login_logo_field_callback',
        'custom-login-logo',
        'custom_login_logo_section'
    );

    add_settings_field(
        'custom_login_background_color',
        'Select Background Color',
        'custom_login_background_color_field_callback',
        'custom-login-logo',
        'custom_login_logo_section'
    );
}
add_action( 'admin_init', 'custom_login_logo_settings_init' );

// Callback for the media uploader (logo upload)
function custom_login_logo_field_callback() {
    $logo_url = get_option('custom_login_logo');
    ?>
    <div>
        <input type="hidden" id="custom_login_logo" name="custom_login_logo" value="<?php echo esc_url( $logo_url ); ?>" />
        <img id="custom_login_logo_preview" src="<?php echo esc_url( $logo_url ); ?>" style="max-height: 100px; width: auto;" />
        <br><br>
        <input type="button" id="custom_login_logo_button" class="button button-secondary" value="Select or Upload Logo" />
        <input type="button" id="custom_login_logo_remove" class="button button-secondary" value="Remove Logo" />
    </div>
    <?php
}

// Callback for the background color field (color picker)
function custom_login_background_color_field_callback() {
    $background_color = get_option('custom_login_background_color', '#ffffff'); // Default to white background
    ?>
    <input type="text" id="custom_login_background_color" name="custom_login_background_color" value="<?php echo esc_attr( $background_color ); ?>" class="color-field" data-default-color="#ffffff" />
    <?php
}

// Process the form data when settings are saved
function custom_login_logo_save_settings() {
    // Verify nonce before processing form data
    if ( isset( $_POST['custom_login_logo_nonce'] ) ) {
        // Unsanitize and sanitize the nonce field
        $nonce = sanitize_text_field( wp_unslash( $_POST['custom_login_logo_nonce'] ) );

        if ( wp_verify_nonce( $nonce, 'custom_login_logo_nonce_action' ) ) {
            // Sanitize inputs after unslashing
            $logo_url = isset( $_POST['custom_login_logo'] ) ? sanitize_text_field( wp_unslash( $_POST['custom_login_logo'] ) ) : '';
            $background_color = isset( $_POST['custom_login_background_color'] ) ? sanitize_text_field( wp_unslash( $_POST['custom_login_background_color'] ) ) : '';

            // Update the options
            update_option( 'custom_login_logo', $logo_url );
            update_option( 'custom_login_background_color', $background_color );

            // Redirect to the settings page after saving
            wp_redirect( admin_url( 'options-general.php?page=custom-login-logo' ) );
            exit;
        } else {
            // Nonce verification failed
            wp_die( esc_html__( 'Nonce verification failed. Please try again.', 'custom-login-logo' ) );
        }
    } else {
        // Nonce is missing
        wp_die( esc_html__( 'Nonce is missing. Please try again.', 'custom-login-logo' ) );
    }
}
add_action( 'admin_post_custom_login_logo_save_settings', 'custom_login_logo_save_settings' );

// Custom logo URL (if you want to customize the URL the logo links to)
function custom_login_logo_url() {
    return home_url();
}
add_filter( 'login_headerurl', 'custom_login_logo_url' );